Documentation
¶
Index ¶
- func ApplyExclusions(all []api.Blueprint, excludeDeep []string, excludeSchema []string, ...) (iterList, dataList []api.Blueprint)
- func CustomPatch(bp api.Blueprint) api.Blueprint
- func CustomPatchEqual(patch, current api.Blueprint) bool
- func IsCustomPatch(bp api.Blueprint) bool
- func IsKnown(identifier string) bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyExclusions ¶
func ApplyExclusions( all []api.Blueprint, excludeDeep []string, excludeSchema []string, skipSystemBlueprints bool, skipSystemBlueprintProperties bool, ) (iterList, dataList []api.Blueprint)
ApplyExclusions filters blueprints for iteration and output. When skipSystemBlueprints is true and skipSystemBlueprintProperties is false, known system blueprint schemas are replaced in dataList by minimal custom property patches.
func CustomPatch ¶
CustomPatch returns a minimal blueprint containing only custom schema additions for known system blueprints.
func CustomPatchEqual ¶
CustomPatchEqual compares a minimal custom system blueprint patch with a full current blueprint by checking only fields present in the patch.
func IsCustomPatch ¶
IsCustomPatch returns true when a blueprint is a minimal patch for a known system blueprint rather than a full blueprint schema.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.